===============================================
django-waitinglist: waiting list app for Django
===============================================

Provides a waiting list for running a private beta with cohorts support.

Requirements
============

* Django 1.4
* django-appconf (included in ``install_requires``)
* django-user-accounts_ (not included in ``install_requires``)

.. _django-user-accounts: https://github.com/pinax/django-user-accounts

Documentation
=============

See http://django-waitinglist.readthedocs.org/
